/* standard-gamepad-button.c generated by valac 0.56.18, the Vala compiler
 * generated from standard-gamepad-button.vala, do not modify */

/*
 * Copyright 2016 Megh Parikh
 *
 * This file is part of LibGamepad.
 *
 * LibGamepad is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * LibGamepad is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public License
 * along with Foobar.  If not, see <http://www.gnu.org/licenses/>.
 */
/* This file is part of GNOME Games. License: GPLv3*/

#include <glib-object.h>

#if !defined(VALA_STRICT_C)
#if !defined(__clang__) && defined(__GNUC__) && (__GNUC__ >= 14)
#pragma GCC diagnostic warning "-Wincompatible-pointer-types"
#elif defined(__clang__) && (__clang_major__ >= 16)
#pragma clang diagnostic ignored "-Wincompatible-function-pointer-types"
#pragma clang diagnostic ignored "-Wincompatible-pointer-types"
#endif
#endif
#if !defined(VALA_EXTERN)
#if defined(_MSC_VER)
#define VALA_EXTERN __declspec(dllexport) extern
#elif __GNUC__ >= 4
#define VALA_EXTERN __attribute__((visibility("default"))) extern
#else
#define VALA_EXTERN extern
#endif
#endif

typedef enum  {
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_A,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_B,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_X,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_Y,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SHOULDER_L,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SHOULDER_R,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_TRIGGER_L,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_TRIGGER_R,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SELECT,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_START,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_STICK_L,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_STICK_R,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_UP,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_DOWN,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_LEFT,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_RIGHT,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_HOME,
	LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_UNKNOWN
} LibGamepadStandardGamepadButton;

#define LIB_GAMEPAD_TYPE_STANDARD_GAMEPAD_BUTTON (lib_gamepad_standard_gamepad_button_get_type ())

VALA_EXTERN GType lib_gamepad_standard_gamepad_button_get_type (void) G_GNUC_CONST ;

static GType
lib_gamepad_standard_gamepad_button_get_type_once (void)
{
	static const GEnumValue values[] = {{LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_A, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_A", "a"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_B, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_B", "b"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_X, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_X", "x"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_Y, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_Y", "y"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SHOULDER_L, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SHOULDER_L", "shoulder-l"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SHOULDER_R, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SHOULDER_R", "shoulder-r"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_TRIGGER_L, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_TRIGGER_L", "trigger-l"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_TRIGGER_R, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_TRIGGER_R", "trigger-r"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SELECT, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_SELECT", "select"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_START, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_START", "start"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_STICK_L, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_STICK_L", "stick-l"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_STICK_R, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_STICK_R", "stick-r"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_UP, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_UP", "dpad-up"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_DOWN, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_DOWN", "dpad-down"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_LEFT, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_LEFT", "dpad-left"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_RIGHT, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_DPAD_RIGHT", "dpad-right"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_HOME, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_HOME", "home"}, {LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_UNKNOWN, "LIB_GAMEPAD_STANDARD_GAMEPAD_BUTTON_UNKNOWN", "unknown"}, {0, NULL, NULL}};
	GType lib_gamepad_standard_gamepad_button_type_id;
	lib_gamepad_standard_gamepad_button_type_id = g_enum_register_static ("LibGamepadStandardGamepadButton", values);
	return lib_gamepad_standard_gamepad_button_type_id;
}

GType
lib_gamepad_standard_gamepad_button_get_type (void)
{
	static volatile gsize lib_gamepad_standard_gamepad_button_type_id__once = 0;
	if (g_once_init_enter (&lib_gamepad_standard_gamepad_button_type_id__once)) {
		GType lib_gamepad_standard_gamepad_button_type_id;
		lib_gamepad_standard_gamepad_button_type_id = lib_gamepad_standard_gamepad_button_get_type_once ();
		g_once_init_leave (&lib_gamepad_standard_gamepad_button_type_id__once, lib_gamepad_standard_gamepad_button_type_id);
	}
	return lib_gamepad_standard_gamepad_button_type_id__once;
}

